.. raw:: html
   :file: fork.html

.. .. container:: twitterbadge

   **Latest news**

   .. raw:: html
      :file: twitter_badge.html

.. include:: definitions.txt

ProcGraph
=========

|procgraph| ("processing graph") is a Python library for rapid prototyping of processing pipelines for logged and realtime data.  New blocks can be added in Python, or using a textual model specification language. 


.. container:: col1

    **Getting started**

    * :ref:`why`
    * :ref:`Download and install <install>`
    * :ref:`tutorial`
    * :ref:`faq`

    **Reference documentation**

    * :ref:`creating_new_blocks`    
    * :ref:`running`    
    * :ref:`packaging`    


.. container:: col2

    **Block libraries documentation**

    * :ref:`Included blocks <library>`

    * Additional libraries (separate packages):
      
      * procgraph_rawseeds_


.. raw:: html
 
   <div style='clear:both'></div>



.. _procgraph_rawseeds: http://andreacensi.github.com/procgraph_rawseeds/


.. 
	.. toctree::
	   :glob:

	   *
	   tutorial/index.rst
	

